@@ -2,18 +2,24 @@
 Generate a colorscheme using Colorz.
 """
 import logging
-import shutil
-import subprocess
 import sys
 
+try:
+    import colorz
+
+except ImportError:
+    logging.error("colorz wasn't found on your system.")
+    logging.error("Try another backend. (wal --backend)")
+    sys.exit(1)
+
 from .. import colors
 from .. import util
 
 
 def gen_colors(img):
     """Generate a colorscheme using Colorz."""
-    cmd = ["colorz", "-n", "6", "--bold", "0", "--no-preview", "--no-bg-img"]
-    return subprocess.check_output([*cmd, img]).splitlines()
+    raw_colors = colorz.colorz(img, n=6, bold_add=0)
+    return [util.rgb_to_hex([*color[0]]) for color in raw_colors]
 
 
 def adjust(cols, light):
@@ -28,10 +34,11 @@ def adjust(cols, light):
 
 def get(img, light=False):
     """Get colorscheme."""
-    if not shutil.which("colorz"):
-        logging.error("Colorz wasn't found on your system.")
-        logging.error("Try another backend. (wal --backend)")
+    cols = gen_colors(img)
+
+    if len(cols) < 6:
+        logging.error("colorz failed to generate enough colors.")
+        logging.error("Try another backend or another image. (wal --backend)")
         sys.exit(1)
 
-    cols = [col.decode('UTF-8').split()[0] for col in gen_colors(img)]
     return adjust(cols, light)
